@@ -24,7 +24,7 @@
 #include "vino-dbus-listener.h"
 #include "vino-dbus.h"
 
-#ifdef HAVE_TELEPATHY_GLIB
+#ifdef VINO_HAVE_TELEPATHY_GLUB
 #include "vino-tube-servers-manager.h"
 #endif
 
@@ -33,6 +33,8 @@
 #include "vino-http.h"
 #endif
 
+#include "vino-mdns.h"
+
 struct _VinoDBusListener
 {
   GObject  parent_instance;
@@ -42,6 +44,10 @@ struct _VinoDBusListener
   gint             screen;
 
   VinoServer      *server;
+
+#ifdef VINO_HAVE_TELEPATHY_GLUB
+  VinoTubeServersManager *manager;
+#endif
 };
 
 typedef GObjectClass VinoDBusListenerClass;
@@ -61,11 +67,11 @@ vino_dbus_listener_finalize (GObject *object)
     g_object_unref (listener->server);
 
 
-#ifdef HAVE_TELEPATHY_GLIB
+#ifdef VINO_HAVE_TELEPATHY_GLUB
   if (listener->manager != NULL)
     {
-      g_object_unref (listener->priv->manager);
-      listener->priv->manager = NULL;
+      g_object_unref (listener->manager);
+      listener->manager = NULL;
     }
 #endif
 
@@ -76,7 +82,7 @@ vino_dbus_listener_finalize (GObject *object)
 static void
 vino_dbus_listener_init (VinoDBusListener *listener)
 {
-#ifdef HAVE_TELEPATHY_GLIB
+#ifdef VINO_HAVE_TELEPATHY_GLUB
   listener->manager = vino_tube_servers_manager_new ();
 #endif
 }
@@ -91,7 +97,7 @@ static guint16
 vino_dbus_listener_get_port (VinoDBusListener *listener)
 {
 #ifdef VINO_ENABLE_HTTP_SERVER
-  return vino_get_http_server_port (listener->server);
+  return vino_get_http_server_port ();
 #else
   return vino_server_get_port (listener->server);
 #endif
@@ -169,7 +175,7 @@ vino_dbus_listener_get_property (GDBusConnection  *connection,
     return g_variant_new_uint16 (vino_server_get_external_port (listener->server));
 
   else if (strcmp (property_name, "AvahiHost") == 0)
-    return g_variant_new_string ("aaa");
+    return g_variant_new_string (vino_mdns_get_hostname());
 
   else
     g_assert_not_reached ();
